@@ -369,6 +369,20 @@ public class Config
      */
     public volatile ConsistencyLevel ideal_consistency_level = null;
 
+    @Deprecated
+    public String otc_coalescing_strategy = "DISABLED";
+
+    @Deprecated
+    public static final int otc_coalescing_window_us_default = 200;
+    @Deprecated
+    public int otc_coalescing_window_us = otc_coalescing_window_us_default;
+    @Deprecated
+    public int otc_coalescing_enough_coalesced_messages = 8;
+    @Deprecated
+    public static final int otc_backlog_expiration_interval_ms_default = 200;
+    @Deprecated
+    public volatile int otc_backlog_expiration_interval_ms = otc_backlog_expiration_interval_ms_default;
+
     public int windows_timer_interval = 0;
 
     /**
