@@ -42,7 +42,7 @@ import org.apache.cassandra.io.util.RandomAccessReader;
 import org.apache.cassandra.service.ActiveRepairService;
 import org.apache.cassandra.utils.*;
 import org.apache.cassandra.utils.concurrent.Refs;
-import org.apache.cassandra.utils.memory.HeapAllocator;
+import org.apache.cassandra.utils.memory.HeapCloner;
 
 public class Scrubber implements Closeable
 {
@@ -819,30 +819,26 @@ public class Scrubber implements Closeable
 
         private Unfiltered fixNegativeLocalExpirationTime(Row row)
         {
-            Row.Builder builder = HeapAllocator.instance.cloningBTreeRowBuilder();
-            builder.newRow(row.clustering());
-            builder.addPrimaryKeyLivenessInfo(row.primaryKeyLivenessInfo().isExpiring() && row.primaryKeyLivenessInfo().localExpirationTime() < 0 ?
-                                              row.primaryKeyLivenessInfo().withUpdatedTimestampAndLocalDeletionTime(row.primaryKeyLivenessInfo().timestamp() + 1, AbstractCell.MAX_DELETION_TIME)
-                                              :row.primaryKeyLivenessInfo());
-            builder.addRowDeletion(row.deletion());
-            for (ColumnData cd : row)
-            {
+            LivenessInfo livenessInfo = row.primaryKeyLivenessInfo();
+            if (livenessInfo.isExpiring() && livenessInfo.localExpirationTime() < 0)
+                livenessInfo = livenessInfo.withUpdatedTimestampAndLocalDeletionTime(livenessInfo.timestamp() + 1, AbstractCell.MAX_DELETION_TIME);
+
+            return row.transformAndFilter(livenessInfo, row.deletion(), cd -> {
                 if (cd.column().isSimple())
                 {
-                    Cell<?> cell = (Cell<?>)cd;
-                    builder.addCell(cell.isExpiring() && cell.localDeletionTime() < 0 ? cell.withUpdatedTimestampAndLocalDeletionTime(cell.timestamp() + 1, AbstractCell.MAX_DELETION_TIME) : cell);
+                    Cell cell = (Cell)cd;
+                    return cell.isExpiring() && cell.localDeletionTime() < 0
+                           ? cell.withUpdatedTimestampAndLocalDeletionTime(cell.timestamp() + 1, AbstractCell.MAX_DELETION_TIME)
+                           : cell;
                 }
                 else
                 {
                     ComplexColumnData complexData = (ComplexColumnData)cd;
-                    builder.addComplexDeletion(complexData.column(), complexData.complexDeletion());
-                    for (Cell<?> cell : complexData)
-                    {
-                        builder.addCell(cell.isExpiring() && cell.localDeletionTime() < 0 ? cell.withUpdatedTimestampAndLocalDeletionTime(cell.timestamp() + 1, AbstractCell.MAX_DELETION_TIME) : cell);
-                    }
+                    return complexData.transformAndFilter(cell -> cell.isExpiring() && cell.localDeletionTime() < 0
+                                                                  ? cell.withUpdatedTimestampAndLocalDeletionTime(cell.timestamp() + 1, AbstractCell.MAX_DELETION_TIME)
+                                                                  : cell);
                 }
-            }
-            return builder.build();
+            }).clone(HeapCloner.instance);
         }
     }
 }
