@@ -652,10 +652,13 @@ public class StreamSession implements IEndpointStateChangeSubscriber
         }
 
         logError(e);
-        // send session failure message
+
         if (messageSender.connected())
+        {
+            state(State.FAILED); // make sure subsequent error handling sees the session in a final state
             messageSender.sendMessage(new SessionFailedMessage());
-        // fail session
+        }
+
         return closeSession(State.FAILED);
     }
 
@@ -1039,6 +1042,12 @@ public class StreamSession implements IEndpointStateChangeSubscriber
 
     public synchronized void abort()
     {
+        if (state.isFinalState())
+        {
+            logger.debug("[Stream #{}] Stream session with peer {} is already in a final state on abort.", planId(), peer);
+            return;
+        }
+
         logger.info("[Stream #{}] Aborting stream session with peer {}...", planId(), peer);
 
         if (getMessageSender().connected())
