@@ -17,14 +17,10 @@
  */
 package org.apache.cassandra.cql3.validation.operations;
 
-import java.util.List;
 import java.util.UUID;
 
 import org.junit.Test;
-import org.junit.runner.RunWith;
 
-import com.datastax.driver.core.PreparedStatement;
-import org.apache.cassandra.OrderedJUnit4ClassRunner;
 import org.apache.cassandra.config.DatabaseDescriptor;
 import org.apache.cassandra.cql3.CQLTester;
 import org.apache.cassandra.db.ColumnFamilyStore;
@@ -35,38 +31,17 @@ import org.apache.cassandra.exceptions.SyntaxException;
 import org.apache.cassandra.locator.InetAddressAndPort;
 import org.apache.cassandra.locator.TokenMetadata;
 import org.apache.cassandra.schema.SchemaConstants;
-import org.apache.cassandra.schema.SchemaKeyspace;
-import org.apache.cassandra.service.ClientWarn;
+import org.apache.cassandra.schema.SchemaKeyspaceTables;
 import org.apache.cassandra.service.StorageService;
 import org.apache.cassandra.utils.FBUtilities;
-import org.assertj.core.api.Assertions;
 
 import static java.lang.String.format;
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNull;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 
-@RunWith(OrderedJUnit4ClassRunner.class)
 public class AlterTest extends CQLTester
 {
-    @Test
-    public void testDropColumnAsPreparedStatement() throws Throwable
-    {
-        String table = createTable("CREATE TABLE %s (key int PRIMARY KEY, value int);");
-
-        PreparedStatement prepared = sessionNet().prepare("ALTER TABLE " + KEYSPACE + "." + table + " DROP value;");
-
-        executeNet("INSERT INTO %s (key, value) VALUES (1, 1)");
-        assertRowsNet(executeNet("SELECT * FROM %s"), row(1, 1));
-
-        sessionNet().execute(prepared.bind());
-
-        executeNet("ALTER TABLE %s ADD value int");
-
-        assertRows(execute("SELECT * FROM %s"), row(1, null));
-    }
-
     @Test
     public void testAddList() throws Throwable
     {
@@ -277,58 +252,6 @@ public class AlterTest extends CQLTester
                                   "max_threshold", "32")));
     }
 
-    @Test
-    public void testCreateAlterKeyspacesRFWarnings() throws Throwable
-    {
-        requireNetwork();
-
-        // NTS
-        ClientWarn.instance.captureWarnings();
-        String ks = createKeyspace("CREATE KEYSPACE %s WITH replication = {'class' : 'NetworkTopologyStrategy', '" + DATA_CENTER + "' : 3 }");
-        List<String> warnings = ClientWarn.instance.getWarnings();
-        assertEquals(1, warnings.size());
-        Assertions.assertThat(warnings.get(0)).contains("Your replication factor 3 for keyspace " + ks + " is higher than the number of nodes 1 for datacenter " + DATA_CENTER);
-
-        ClientWarn.instance.captureWarnings();
-        execute("CREATE TABLE " + ks + ".t (k int PRIMARY KEY, v int)");
-        warnings = ClientWarn.instance.getWarnings();
-        assertNull(warnings);
-
-        ClientWarn.instance.captureWarnings();
-        execute("ALTER KEYSPACE " + ks + " WITH replication = {'class' : 'NetworkTopologyStrategy', '" + DATA_CENTER + "' : 2 }");
-        warnings = ClientWarn.instance.getWarnings();
-        assertEquals(1, warnings.size());
-        Assertions.assertThat(warnings.get(0)).contains("Your replication factor 2 for keyspace " + ks + " is higher than the number of nodes 1 for datacenter " + DATA_CENTER);
-
-        ClientWarn.instance.captureWarnings();
-        execute("ALTER KEYSPACE " + ks + " WITH replication = {'class' : 'NetworkTopologyStrategy', '" + DATA_CENTER + "' : 1 }");
-        warnings = ClientWarn.instance.getWarnings();
-        assertNull(warnings);
-
-        // SimpleStrategy
-        ClientWarn.instance.captureWarnings();
-        ks = createKeyspace("CREATE KEYSPACE %s WITH replication = { 'class' : 'SimpleStrategy', 'replication_factor' : 3 }");
-        warnings = ClientWarn.instance.getWarnings();
-        assertEquals(1, warnings.size());
-        Assertions.assertThat(warnings.get(0)).contains("Your replication factor 3 for keyspace " + ks + " is higher than the number of nodes 1");
-
-        ClientWarn.instance.captureWarnings();
-        execute("CREATE TABLE " + ks + ".t (k int PRIMARY KEY, v int)");
-        warnings = ClientWarn.instance.getWarnings();
-        assertNull(warnings);
-
-        ClientWarn.instance.captureWarnings();
-        execute("ALTER KEYSPACE " + ks + " WITH replication = { 'class' : 'SimpleStrategy', 'replication_factor' : 2 }");
-        warnings = ClientWarn.instance.getWarnings();
-        assertEquals(1, warnings.size());
-        Assertions.assertThat(warnings.get(0)).contains("Your replication factor 2 for keyspace " + ks + " is higher than the number of nodes 1");
-
-        ClientWarn.instance.captureWarnings();
-        execute("ALTER KEYSPACE " + ks + " WITH replication = { 'class' : 'SimpleStrategy', 'replication_factor' : 1 }");
-        warnings = ClientWarn.instance.getWarnings();
-        assertNull(warnings);
-    }
-
     @Test
     public void testCreateAlterNetworkTopologyWithDefaults() throws Throwable
     {
@@ -527,7 +450,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "16", "class", "org.apache.cassandra.io.compress.LZ4Compressor")));
@@ -536,7 +459,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "32", "class", "org.apache.cassandra.io.compress.SnappyCompressor")));
@@ -545,7 +468,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "64", "class", "org.apache.cassandra.io.compress.LZ4Compressor")));
@@ -554,7 +477,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "16", "class", "org.apache.cassandra.io.compress.LZ4Compressor", "min_compress_ratio", "2.0")));
@@ -563,7 +486,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "16", "class", "org.apache.cassandra.io.compress.LZ4Compressor", "min_compress_ratio", "1.0")));
@@ -572,7 +495,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("chunk_length_in_kb", "16", "class", "org.apache.cassandra.io.compress.LZ4Compressor")));
@@ -582,7 +505,7 @@ public class AlterTest extends CQLTester
 
         assertRows(execute(format("SELECT compression FROM %s.%s WHERE keyspace_name = ? and table_name = ?;",
                                   SchemaConstants.SCHEMA_KEYSPACE_NAME,
-                                  SchemaKeyspace.TABLES),
+                                  SchemaKeyspaceTables.TABLES),
                            KEYSPACE,
                            currentTable()),
                    row(map("enabled", "false")));
@@ -721,4 +644,15 @@ public class AlterTest extends CQLTester
 
         assertInvalidMessage("DROP COMPACT STORAGE is disabled. Enable in cassandra.yaml to use.", "ALTER TABLE %s DROP COMPACT STORAGE");
     }
+
+    /**
+     * Test for CASSANDRA-14564
+     */
+    @Test
+    public void testAlterByAddingColumnToCompactTableShouldFail() throws Throwable
+    {
+        createTable("CREATE TABLE %s (a int, b int, PRIMARY KEY (a, b)) WITH COMPACT STORAGE");
+        assertInvalidMessage("Cannot add new column to a COMPACT STORAGE table",
+                             "ALTER TABLE %s ADD column1 text");
+    }
 }
